@@ -4,29 +4,7 @@ import logging
 logger = logging.getLogger("pyuploadcare")
 
 
-RESIZER_BASE = 'http://services.uploadcare.com/resizer/%(file_id)s/%(cmd_line)s/'
-
-
-class LazyFile(object):
-    def __init__(self, id, ucare):
-        self.id = id
-        self.ucare = ucare
-
-    def load_data(self):
-        return self.ucare.make_request('GET', '/files/download/%s/' % self.id)
-
-    def wait(self):
-        while True:
-            data = self.load_data()
-            logger.debug('loaded data %s' % data)
-
-            if data['status'] == 'success':
-                return File(data['file_id'], self.ucare)
-
-            if data['status'] not in ('progress', 'unknown'):
-                raise Exception('Invalid task status')
-
-            time.sleep(0.1)
+RESIZER_BASE = 'http://services.uploadcare.com/resizer/{file_id}/{cmd_line}/'
 
 
 class File(object):
@@ -46,22 +24,48 @@ class File(object):
 
         return super(File, self).__getattr__(name)
 
-    def keep(self, wait=False):
-        self._info = self.ucare.make_request('POST', self.api_uri, {'keep': 1})
+    def keep(self, **kwargs):
+        """Deprecated method.
+
+        Use store instead.
+        Will be removed eventually.
+        """
+        logger.warn("keep() is deprecated, use store() instead")
+        return self.store(**kwargs)
+
+    def store(self, wait=False, timeout=5):
+        if self.ucare.api_version == '0.1':
+            self._info = self.ucare.make_request('POST', self.api_uri, data={
+                'keep': 1
+            })
+        else:
+            self.ucare.make_request('PUT', self.storage_uri)
 
         if wait:
+            time_started = time.time()
             while not self.info['on_s3']:
+                if time.time() - time_started > timeout:
+                    raise Exception('timed out trying to store')
                 self.update_info()
                 time.sleep(0.1)
+        self.update_info()
 
-    def delete(self):
+    def delete(self, wait=False, timeout=5):
         self.ucare.make_request('DELETE', self.api_uri)
 
+        if wait:
+            time_started = time.time()
+            while self.info['removed'] is None:
+                if time.time() - time_started > timeout:
+                    raise Exception('timed out trying to delete')
+                self.update_info()
+                time.sleep(0.1)
+        self.update_info()
+
     @property
     def info(self):
         if not self._info:
             self.update_info()
-
         return self._info
 
     def update_info(self):
@@ -69,12 +73,18 @@ class File(object):
 
     @property
     def api_uri(self):
-        return '/files/%s/' % self.file_id
+        return '/files/{}/'.format(self.file_id)
+
+    @property
+    def storage_uri(self):
+        return '/files/{}/storage/'.format(self.file_id)
 
     def serialize(self):
         """Returns a string suitable to be stored somewhere.
-        It's either an URL (to save a request) or just file-id"""
 
+        It's either an URL (to save a request) or just file-id.
+
+        """
         if self._info and self.url:
             return self.url
 
@@ -84,32 +94,26 @@ class File(object):
     def url(self):
         if self._cached_url:
             return self._cached_url
-
         return self.info['original_file_url']
 
     @property
     def filename(self):
         if not self.url:
             return ''
-
         return self.url.split('/')[-1]
 
     def resized(self, width=None, height=None, crop=False):
         dimensions = str(width or '')
-
         if height:
             dimensions += 'x%i' % height
 
         chunks = [dimensions]
-
         if crop:
             chunks.append('crop')
 
         cmd_line = '/'.join(chunks)
-
-        return RESIZER_BASE % {'file_id': self.file_id, 'cmd_line': cmd_line}
+        return RESIZER_BASE.format(file_id=self.file_id, cmd_line=cmd_line)
 
     def string_resized(self, cmd_line):
         cmd_line = cmd_line.replace('_', '/')
-
-        return RESIZER_BASE % {'file_id': self.file_id, 'cmd_line': cmd_line}
+        return RESIZER_BASE.format(file_id=self.file_id, cmd_line=cmd_line)
